Encoding: UTF-8
Package: NPHazardRate
Type: Package
Title: Nonparametric Hazard Rate Estimation
Version: 0.1
URL:
Date: 2018-10-13
Authors@R: c(person("Dimitrios", "Bagkavos", role = c("aut", "cre"), email = "dimitrios.bagkavos@gmail.com") )
Author: Dimitrios Bagkavos [aut, cre]
Maintainer: Dimitrios Bagkavos <dimitrios.bagkavos@gmail.com>
Depends: R (>= 3.5.0)
Imports: stats, survival
Description: Provides functions and examples for histogram, kernel (classical, variable bandwidth and transformations based), discrete and semiparametric hazard rate estimators.
License: GPL (>= 2)
NeedsCompilation: no
RoxygenNote: 6.1.0
Packaged: 2018-10-28 21:38:17 UTC; dimitris
Repository: CRAN
Date/Publication: 2018-11-02 18:10:18 UTC
Built: R 4.6.0; ; 2026-04-26 04:22:27 UTC; unix
