Encoding: UTF-8
Package: NPHazardRate
Type: Package
Title: Nonparametric Hazard Rate Estimation
Version: 0.3
URL:
Date: 2026-07-22
Authors@R: c(person("Dimitrios", "Bagkavos", role = c("aut", "cre"), email = "dimitrios.bagkavos@gmail.com") )
Author: Dimitrios Bagkavos [aut, cre]
Maintainer: Dimitrios Bagkavos <dimitrios.bagkavos@gmail.com>
Depends: R (>= 3.5.0)
Imports: stats, survival
Description: Provides functions and examples for histogram, kernel (classical, variable bandwidth and transformations based, see e.g. Bagkavos (2008), <doi:10.1080/10485250802440184>, discrete and semiparametric hazard rate estimators.
License: GPL (>= 2)
NeedsCompilation: no
Config/roxygen2/version: 8.0.0
Packaged: 2026-07-22 11:24:11 UTC; Dimitrios Bagkavos
Repository: CRAN
Date/Publication: 2026-07-22 13:00:17 UTC
